#!/usr/bin/env python

"""
Compose 2 RGBA images


Copyright 2011 Thorsten Wilms
License: GPLv3, see docs/COPYING

This program is free software: you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation, either version 3 of the License, or (at your option) any later
version.

This program is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.

"""
from __future__ import division
import numpy
import Image


def alpha_composite(lower, upper):
    """Compose 2 RGBA images."""

    lower = numpy.asarray(lower)
    upper = numpy.asarray(upper)
    comp = numpy.empty(upper.shape, dtype='float')
    alpha = numpy.index_exp[:,:,3:]
    rgb = numpy.index_exp[:,:,:3]
    u_alpha = upper[alpha] / 255.0
    l_alpha = lower[alpha] / 255.0
    comp[alpha] = u_alpha + l_alpha * (1 - u_alpha)
    denominator = upper[rgb] * u_alpha + lower[rgb] * l_alpha * (1 - u_alpha)
    comp[rgb] = denominator / comp[alpha]
    comp[alpha] *= 255
    upper_transparent = (u_alpha <= 0.001) & (l_alpha > 0.001)
    comp[upper_transparent] = lower[upper_transparent]
    lower_transparent = (l_alpha <= 0.001) & (u_alpha > 0.001)
    comp[lower_transparent] = upper[lower_transparent]
    comp[comp > 255] = 255
    # astype('uint8') maps numpy.nan and numpy.inf to 0
    comp = comp.astype('uint8')
    comp = Image.fromarray(comp,'RGBA')

    return comp
