#!/usr/bin/env python

"""
Background Context Extractor module

Takes one screenshot with white, and one with shadow-color (usually black),
background. Puts out a PNG image with transparent desktop.

This is usefull for evaluationg wallpapers that should go well with panels
and themes other than the one you are currently using.


Copyright 2010, 2011 Thorsten Wilms
License: GPLv3, see docs/COPYING

This program is free software: you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation, either version 3 of the License, or (at your option) any later
version.

This program is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.

"""
import Image
from ImageChops import difference
from ImageChops import invert
from ImageOps import autocontrast
from os.path import exists
from sys import stdout

# Custom modules
from backtestground.common import move_to_numbered_backup


def extract(file_white, file_shadow, destination, overwrite):
    """Make desktop of a screenshot transparent. Takes 2 screenshots: with
    white desktop, with shadow-color (usually black).

    """
    white = Image.open(file_white)
    shadow = Image.open(file_shadow)

    # Difference between the images.
    # Result is black where they are the same.
    mask = difference(white, shadow)

    # Turn mask into single 8-bit channel so it can be used with putalpha
    mask_l = mask.convert('L')

    # Black will mean transparent, so invert it
    mask_l = invert(mask_l)

    # If the shadow isn't black, the darkest color in the mask will be grey.
    # Normalize to guarantee it will be black.
    mask_l = autocontrast(mask_l)

    # Apply mask
    shadow.putalpha(mask_l)

    # Save result
    if not overwrite and exists(destination):
        move_to_numbered_backup(destination)
    shadow.save(destination)

    stdout.write("Saved %s.\n" % destination)
