import ez_setup
ez_setup.use_setuptools()

import os
from os.path import isdir
from setuptools import setup
from setuptools import find_packages

# Utility function to read the README file.
def read(fname):
    return open(os.path.join(os.path.dirname(__file__), fname)).read()


# Only install templates if ~/Templates exists
home = os.getenv("HOME")
templates = ''.join([home, '/Templates'])

if isdir(templates):
    template_files = (templates, ['templates/bg_template_2560x1600.svg',
                                   'templates/bg_template_2560x1600.xcf'])
else:
    template_files = ''


# Man pages
man_path = '/usr/local/man/man1'

if isdir(man_path):
    man_files = (man_path, ['man/combine-per-resolution.1',
                            'man/context-to-common-resolutions.1',
                            'man/extract-background-context.1',
                            'man/to-common-resolutions.1'])
else:
    man_files = ''


data_files = [template_files, man_files]


setup(
    name="Backtestground",
    version="0.2",
    author="Thorsten Wilms",
    author_email="t_w_@freenet.de",
    description=("A collection of templates and utilities for the creation "
                   "and evaluation of desktop backgrounds (wallpapers)."),
    license="GPLv3",
    keywords="background wallpaper images utility templates",
    url="https://launchpad.net/backtestground",
    long_description=read('docs/README'),
    classifiers=[
        "Development Status :: 4 - Beta",
        "Environment :: Console",
        "Intended Audience :: Other Audience",
        "License :: OSI Approved :: GNU General Public License (GPL)",
        "Natural Language :: English",
        "Operating System :: POSIX",
        "Programming Language :: Python",
        "Topic :: Multimedia :: Graphics :: Graphics Conversion",
        "Topic :: Utilities"],
    zip_safe=True,
    package_dir={'':'lib'},
    packages=['backtestground'],
    scripts=['bin/combine-per-resolution',
             'bin/context-to-common-resolutions',
             'bin/extract-background-context',
             'bin/to-common-resolutions'],
    data_files=data_files
)
